package com.vernaio.example;

import java.io.File;

import com.vernaio.aivis.engine.v2.base.sdk.EngineLogger;
import com.vernaio.aivis.engine.v2.dependency.analysis.sdk.DependencyAnalysis;
import com.vernaio.aivis.engine.v2.dependency.analysis.sdk.DependencyAnalysisData;
import com.vernaio.aivis.engine.v2.dependency.analysis.sdk.DependencyAnalysisSetup;
import com.vernaio.aivis.engine.v2.dependency.analysis.sdk.dto.DtoAnalysisConfig;
import com.vernaio.aivis.engine.v2.dependency.analysis.sdk.dto.DtoClusteringConfig;
import com.vernaio.aivis.engine.v2.dependency.analysis.sdk.dto.DtoSamplingConfig;

public class Main {
	
	private static final int MIN_LOGGING_LEVEL = 3;
	
	private static final int MAX_THREADS = 0; // max threads 0 means the number of threads will be chosen automatically
	
	private static final String DATA_FILE = "train_da.csv";
	
	public static void main(final String[] args) throws Exception {
		
		System.out.println("Setup ...");
		// parsing args as folder config
		final FolderConfig folderConfig = FolderConfig.fromArgs(args);
		// create and register logger
		DependencyAnalysisSetup.registerLogger(new EngineLogger() {
			
			@Override
			public void log(int level, String thread, String module, String message) {
				if (level <= MIN_LOGGING_LEVEL) {
					System.out.println(String.format("\t... %s", message));
				}
			}
		});
		// init thread count
		DependencyAnalysisSetup.initThreadCount(MAX_THREADS);
		System.out.println("\t... done!");
		
		/*
		 * DATA READING
		 */
		
		System.out.println("Loading data ...");
		final DependencyAnalysisData data = Utils.readCsvConvertToAivisFormat(new File(folderConfig.getInputFolder(), DATA_FILE));
		
		/*
		 * ANALYSIS
		 */
		
		System.out.println("Creating analysis ...");
		// build analysis config - for more options here, see documentation
		final DtoAnalysisConfig analysisConfig =
			new DtoAnalysisConfig().withClustering(new DtoClusteringConfig().withMinimalClusterSize(1).withOutputMultipleZoomLevels(true))
				.withSampling(new DtoSamplingConfig().withMaximalSampleCount(10000));
		
		// create analysis
		final DependencyAnalysis analysis = DependencyAnalysis.create(data, analysisConfig);
		System.out.println("\t... done!");
		
		// write report file and close
		System.out.println("Retrieving and saving analysis file ...");
		Utils.writeJson(new File(folderConfig.getOutputFolder(), "analysis-report.json"), analysis.getReport());
		System.out.println("\t... done!");
		
		data.destroy();
		System.out.println("\t... all done!");
		return;
		
	}
	
}
